# Python notebooks

This folder contains a set of python notebooks to show usage of the `biobroker` library. It currently contains:

## Biosamples
1. Full submission example with no validation
2. Validation against checklist example
3. How to modify your input source metadata before submission
4. How to retrieve samples after submission
5. How to update the samples
6. How to submit complex metadata

It is not necessary to view them in this order; However, it is *highly recommended*. One of the reasons it is recommended
is because... well, example number 1 contains instructions on library install. Follow at your _own risk_!

